@@ -215,20 +215,30 @@ class QueryDetail(BaseModel):
 
 #############################
 
+class JobSummary(BaseModel):
+    jobEid: str
+    jobName: str
+    lastJobRunState: Optional[str]
+    lastStartedOn: Optional[str]
+    lastCompletedOn: Optional[str]
+    lastExecutionTime: Optional[int]
+
+class JobSummaries(BaseModel):
+    __root__: List[JobSummary]
+
 
 class Command(BaseModel):
     name: str
     scriptLocation: str
     pythonVersion: str
 
-
-class Job(BaseModel):  # JobSummary+JobDetails
+class JobDetail(BaseModel):
     jobEid: str
     jobName: str
     description: str
     role: str
-    createdOn: str  # TODO: validator
-    lastModifiedOn: str  # TODO: validator
+    createdOn: str
+    lastModifiedOn: str
     glueVersion: str
     maxRetries: int
     allocatedCapacity: int
@@ -239,15 +249,11 @@ class Job(BaseModel):  # JobSummary+JobDetails
     command: Optional[Command]
     defaultArguments: Optional[Dict]
     lastJobRunState: Optional[str]
-    lastStartedOn: Optional[str]  # TODO: validator
-    lastCompletedOn: Optional[str]  # TODO: validator
+    lastStartedOn: Optional[str]
+    lastCompletedOn: Optional[str]
     lastExecutionTime: Optional[int]
 
 
-class Jobs(BaseModel):
-    __root__: List[Job]
-
-
 class JobRun(BaseModel):
     jobRunAwsId: str
     jobName: str
@@ -313,8 +319,8 @@ class EidCache(BaseModel):
     created_at: Optional[str]
 
 
-class JobsWithLastRunCache(BaseModel):
-    jobs: Jobs
+class JobSummariesCache(BaseModel):
+    jobs: JobSummaries
     created_at: Optional[str]
 
 
